@@ -1,4 +1,6 @@
-from django.conf.urls.defaults import url, patterns
+from __future__ import absolute_import, unicode_literals
+
+from django.conf.urls import url, patterns
 
 
 urlpatterns = patterns(
