@@ -1,3 +1,5 @@
+from __future__ import absolute_import, unicode_literals
+
 from django.db.models import F
 from django.http import HttpResponse, HttpResponseRedirect
 from django.shortcuts import get_object_or_404
@@ -12,7 +14,7 @@ def click(request, code):
 
 
 def impression(request, code):
-    if (not request.is_ajax() and Banner.objects.filter(code=code).update(
+    if (request.is_ajax() and Banner.objects.filter(code=code).update(
             impressions=F('impressions') + 1
             )):
         return HttpResponse('+1')
